psychopy_ext.exp.Task.wait_until_response — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.exp.Task.wait_until_response

`Task.` `wait_until_response`(draw_stim=True)

  Waits until a response key is pressed.

  Returns last key pressed, timestamped.

  Kwargs: | draw_stim (bool, default: True) Controls if stimuli should be drawn or have already been drawn (useful if you only want to redefine the drawing bit of this function).
  Returns: | A list of tuples with a key name (str) and a response time (float).